@@ -18,16 +18,27 @@
 */
 
 /*
- * $Id: ccid.c 6885 2014-04-11 18:46:19Z rousseau $
+ * $Id$
  */
 
+#include <config.h>
+
+#ifdef HAVE_STDIO_H
 #include <stdio.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <pcsclite.h>
 #include <ifdhandler.h>
 
-#include "config.h"
 #include "debug.h"
 #include "ccid.h"
 #include "defs.h"
@@ -50,12 +61,6 @@ int ccid_open_hack_pre(unsigned int reader_index)
 
 	switch (ccid_descriptor->readerID)
 	{
-		case CARDMAN3121+1:
-			/* Reader announces APDU but is in fact TPDU */
-			ccid_descriptor->dwFeatures &= ~CCID_CLASS_EXCHANGE_MASK;
-			ccid_descriptor->dwFeatures |= CCID_CLASS_TPDU;
-			break;
-
 		case MYSMARTPAD:
 			ccid_descriptor->dwMaxIFSD = 254;
 			break;
@@ -66,19 +71,7 @@ int ccid_open_hack_pre(unsigned int reader_index)
 			ccid_descriptor->readTimeout = 60*1000; /* 60 seconds */
 			break;
 
-		case GEMPCTWIN:
-		case GEMPCKEY:
-		case DELLSCRK:
-			/* Only the chipset with firmware version 2.00 is "bogus"
-			 * The reader may send packets of 0 bytes when the reader is
-			 * connected to a USB 3 port */
-			if (0x0200 == ccid_descriptor->IFD_bcdDevice)
-			{
-				ccid_descriptor->zlp = TRUE;
-				DEBUG_INFO("ZLP fixup");
-			}
-			break;
-
+		case OZ776:
 		case OZ776_7772:
 			ccid_descriptor->dwMaxDataRate = 9600;
 			break;
@@ -148,7 +141,7 @@ static void dump_gemalto_firmware_features(struct GEMALTO_FIRMWARE_FEATURES *gff
 	DEBUG_INFO2(" bEntryValidationCondition: 0x%02X",
 		gff->bEntryValidationCondition);
 
-	DEBUG_INFO(" Reader supports PC/SCv2 features:");
+	DEBUG_INFO1(" Reader supports PC/SCv2 features:");
 	DEBUG_INFO2("  VerifyPinStart: %s", YESNO(gff->VerifyPinStart));
 	DEBUG_INFO2("  VerifyPinFinish: %s", YESNO(gff->VerifyPinFinish));
 	DEBUG_INFO2("  ModifyPinStart: %s", YESNO(gff->ModifyPinStart));
@@ -203,8 +196,8 @@ static void set_gemalto_firmware_features(unsigned int reader_index)
 		unsigned int len_features = sizeof *gf_features;
 		RESPONSECODE ret;
 
-		ret = CmdEscape(reader_index, cmd, sizeof cmd,
-			(unsigned char*)gf_features, &len_features, 0);
+		ret = CmdEscapeCheck(reader_index, cmd, sizeof cmd,
+			(unsigned char*)gf_features, &len_features, 0, TRUE);
 		if ((IFD_SUCCESS == ret) &&
 		    (len_features == sizeof *gf_features))
 		{
@@ -519,8 +512,10 @@ int ccid_open_hack_post(unsigned int reader_index)
  *					ccid_error
  *
  ****************************************************************************/
-void ccid_error(int error, const char *file, int line, const char *function)
+void ccid_error(int log_level, int error, const char *file, int line,
+	const char *function)
 {
+#ifndef NO_LOG
 	const char *text;
 	char var_text[30];
 
@@ -637,7 +632,8 @@ void ccid_error(int error, const char *file, int line, const char *function)
 			text = var_text;
 			break;
 	}
-	log_msg(PCSC_LOG_ERROR, "%s:%d:%s %s", file, line, function, text);
+	log_msg(log_level, "%s:%d:%s %s", file, line, function, text);
+#endif
 
 } /* ccid_error */
 
